@@ -30,6 +30,14 @@ module Sprockets
         end
       end
 
+      class AbsoluteAssetPathError < ArgumentError
+        def initialize(bad_path, good_path, prefix)
+          msg = "Asset names passed to helpers should not include the #{prefix.inspect} prefix. " <<
+                "Instead of #{bad_path.inspect}, use #{good_path.inspect}"
+          super(msg)
+        end
+      end
+
       if defined? ActionView::Helpers::AssetUrlHelper
         include ActionView::Helpers::AssetUrlHelper
         include ActionView::Helpers::AssetTagHelper
@@ -77,17 +85,12 @@ module Sprockets
       # Computes the full URL to a asset in the public directory. This
       # method checks for errors before returning path.
       def asset_path(source, options = {})
-        check_errors_for(source, options)
-        path_to_asset(source, options)
-      end
-      alias :path_to_asset_with_errors :asset_path
-
-      # Computes the full URL to a asset in the public directory. This
-      # will use +asset_path+ internally, so most of their behaviors
-      # will be the same.
-      def asset_url(source, options = {})
-        path_to_asset_with_errors(source, options.merge(:protocol => :request))
+        unless options[:debug]
+          check_errors_for(source, options)
+        end
+        super(source, options)
       end
+      alias :path_to_asset :asset_path
 
       # Get digest for asset path.
       #
@@ -173,17 +176,30 @@ module Sprockets
         def check_dependencies!(dep)
           depend_on(dep)
           depend_on_asset(dep)
+        rescue Sprockets::FileNotFound
         end
 
-        # Raise errors when source does not exist or is not in the precompiled list
+        # Raise errors when source is not in the precompiled list, or
+        # incorrectly contains the assets_prefix.
         def check_errors_for(source, options)
+          return unless self.raise_runtime_errors
+
           source = source.to_s
-          return source if !self.raise_runtime_errors || source.blank? || source =~ URI_REGEXP
+          return if source.blank? || source =~ URI_REGEXP
+
           asset = lookup_asset_for_path(source, options)
 
           if asset && asset_needs_precompile?(asset.logical_path, asset.pathname.to_s)
             raise AssetFilteredError.new(asset.logical_path)
           end
+
+          full_prefix = File.join(self.assets_prefix || "/", '')
+          if !asset && source.start_with?(full_prefix)
+            short_path = source[full_prefix.size, source.size]
+            if lookup_asset_for_path(short_path, options)
+              raise AbsoluteAssetPathError.new(source, short_path, full_prefix)
+            end
+          end
         end
 
         # Returns true when an asset will not be available after precompile is run
