@@ -1,6 +1,7 @@
 require 'rake'
 require 'rake/sprocketstask'
 require 'sprockets'
+require 'action_view'
 require 'action_view/base'
 
 module Sprockets
@@ -37,6 +38,14 @@ module Sprockets
         end
       end
 
+      def manifest
+        if app
+          Sprockets::Manifest.new(index, output, app.config.assets.manifest)
+        else
+          super
+        end
+      end
+
       def cache_path
         if app
           "#{app.config.root}/tmp/cache/assets"
